@@ -86,7 +86,7 @@
 #define KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGWIDGETS_NO_DEPRECATED
-#  define KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56500
+#  define KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56600
 #endif
 #ifdef KCONFIGWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56500
+#    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56600
 #  endif
 #endif
 
@@ -199,6 +199,12 @@
 #else
 #  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_93(text)
 #endif
+
+#if KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56600
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_102(text) KCONFIGWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_102(text)
+#endif
 #define KCONFIGWIDGETS_DEPRECATED_VERSION_4(minor, text)      KCONFIGWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KCONFIGWIDGETS_DEPRECATED_VERSION_5(minor, text)      KCONFIGWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KCONFIGWIDGETS_DEPRECATED_VERSION(major, minor, text) KCONFIGWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
@@ -267,7 +273,7 @@
 #define KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGWIDGETS_NO_DEPRECATED
-#  define KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56500
+#  define KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56600
 #endif
 #ifdef KCONFIGWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -277,7 +283,7 @@
 #  ifdef KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56500
+#    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56600
 #  endif
 #endif
 
@@ -380,6 +386,12 @@
 #else
 #  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_93(text)
 #endif
+
+#if KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56600
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_102(text) KCONFIGWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_102(text)
+#endif
 #define KCONFIGWIDGETS_DEPRECATED_VERSION_4(minor, text)      KCONFIGWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KCONFIGWIDGETS_DEPRECATED_VERSION_5(minor, text)      KCONFIGWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KCONFIGWIDGETS_DEPRECATED_VERSION(major, minor, text) KCONFIGWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
